#### Tableau tools for Agentic use cases with Langchain

This project builds Agentic tools from Tableau capabilities for use within the [Langchain](https://www.langchain.com/) and [LangGraph](https://langchain-ai.github.io/langgraph/tutorials/introduction/) frameworks.


[View Main Project Documentation](../README.md)

